@@ -193,7 +193,9 @@ class PythonTranslator(Translator):
                 fm = black.FileMode(string_normalization=False)
                 content = black.format_str(content, mode=fm)
             except ImportError:
-                logger.warning("Black is not installed, parameters wont be formatted")
+                logger.debug("Black is not installed, parameters won't be formatted")
+            except AttributeError as aerr:
+                logger.warning(f"Black encountered an error, skipping formatting ({aerr})")
         return content
 
     @classmethod
